@@ -2621,10 +2621,16 @@ struct dive *merge_dives(const struct dive *a, const struct dive *b, int offset,
 	MERGE_TXT(res, a, b, suit, ", ");
 	MERGE_MAX(res, a, b, number);
 	MERGE_NONZERO(res, a, b, visibility);
+	MERGE_NONZERO(res, a, b, wavesize);
+	MERGE_NONZERO(res, a, b, current);
+	MERGE_NONZERO(res, a, b, surge);
+	MERGE_NONZERO(res, a, b, chill);
 	copy_pictures(a->pictures.nr ? &a->pictures : &b->pictures, &res->pictures);
 	taglist_merge(&res->tag_list, a->tag_list, b->tag_list);
-	cylinders_map_a = malloc(a->cylinders.nr * sizeof(*cylinders_map_a));
-	cylinders_map_b = malloc(b->cylinders.nr * sizeof(*cylinders_map_b));
+	/* if we get dives without any gas / cylinder information in an import, make sure
+	 * that there is at leatst one entry in the cylinder map for that dive */
+	cylinders_map_a = malloc(MAX(1, a->cylinders.nr) * sizeof(*cylinders_map_a));
+	cylinders_map_b = malloc(MAX(1, b->cylinders.nr) * sizeof(*cylinders_map_b));
 	merge_cylinders(res, a, b, cylinders_map_a, cylinders_map_b);
 	merge_equipment(res, a, b);
 	merge_temperatures(res, a, b);
@@ -3493,8 +3499,11 @@ extern bool cylinder_with_sensor_sample(const struct dive *dive, int cylinder_id
 {
 	for (const struct divecomputer *dc = &dive->dc; dc; dc = dc->next) {
 		for (int i = 0; i < dc->samples; ++i) {
+			struct sample *sample = dc->sample + i;
 			for (int j = 0; j < MAX_SENSORS; ++j) {
-				if (dc->sample[i].sensor[j] == cylinder_id)
+				if (!sample->pressure[j].mbar)
+					continue;
+				if (sample->sensor[j] == cylinder_id)
 					return true;
 			}
 		}
