@@ -677,8 +677,21 @@ static dc_status_t libdc_header_parser(dc_parser_t *parser, device_data_t *devda
 		download_error(translate("gettextFromC", "Error obtaining water salinity"));
 		return rc;
 	}
-	if (rc == DC_STATUS_SUCCESS)
+	if (rc == DC_STATUS_SUCCESS) {
 		dive->dc.salinity = lrint(salinity.density * 10.0);
+		if (dive->dc.salinity == 0) {
+			// sometimes libdivecomputer gives us density values, sometimes just
+			// a water type and a density of zero; let's make this work as best as we can
+			switch (salinity.type) {
+			case DC_WATER_FRESH:
+				dive->dc.salinity = FRESHWATER_SALINITY;
+				break;
+			default:
+				dive->dc.salinity = SEAWATER_SALINITY;
+				break;
+			}
+		}
+	}
 
 	double surface_pressure = 0;
 	rc = dc_parser_get_field(parser, DC_FIELD_ATMOSPHERIC, 0, &surface_pressure);
@@ -818,6 +831,14 @@ static int dive_cb(const unsigned char *data, unsigned int size,
 		dive->dc.sample[0].temperature.mkelvin = 0;
 	}
 
+	/* special case for bug in Tecdiving DiveComputer.eu
+	 * often the first sample has a water temperature of 0C, followed by the correct
+	 * temperature in the next sample */
+	if (same_string(dive->dc.model, "Tecdiving DiveComputer.eu") &&
+	    dive->dc.sample[0].temperature.mkelvin == ZERO_C_IN_MKELVIN &&
+	    dive->dc.sample[1].temperature.mkelvin > dive->dc.sample[0].temperature.mkelvin)
+		dive->dc.sample[0].temperature.mkelvin = dive->dc.sample[1].temperature.mkelvin;
+
 	record_dive_to_table(dive, devdata->download_table);
 	return true;
 
