@@ -11,7 +11,6 @@
 
 #include <QFont>
 #include <QFontMetrics>
-#include <QSize>
 
 QFont defaultModelFont();
 QFontMetrics defaultModelFontMetrics();
@@ -27,11 +26,9 @@ struct IconMetrics {
 	// icon spacing
 	int spacing; // ex 2px
 	// devicePixelRatio
-	double dpr; // 1.0 for traditional screens, HiDPI screens up to 3.0
 	IconMetrics();
 };
 
 const IconMetrics &defaultIconMetrics();
-void updateDevicePixelRatio(double dpr);
 
 #endif // METRICS_H
