@@ -25,7 +25,7 @@ struct DiveField {
 	unsigned int water_temp : 1;
 	unsigned int atm_press : 1;
 	unsigned int divesite : 1;
-	unsigned int divemaster : 1;
+	unsigned int diveguide : 1;
 	unsigned int buddy : 1;
 	unsigned int rating : 1;
 	unsigned int visibility : 1;
@@ -49,7 +49,7 @@ struct DiveField {
 		WATER_TEMP = 1 << 5,
 		ATM_PRESS = 1 << 6,
 		DIVESITE = 1 << 7,
-		DIVEMASTER = 1 << 8,
+		DIVEGUIDE = 1 << 8,
 		BUDDY = 1 << 9,
 		RATING = 1 << 10,
 		VISIBILITY = 1 << 11,
@@ -96,6 +96,8 @@ signals:
 	void divesTimeChanged(timestamp_t delta, const QVector<dive *> &dives);
 	void divesImported(); // A general signal when multiple dives have been imported.
 
+	void diveComputerEdited(divecomputer *dc);
+
 	void cylindersReset(const QVector<dive *> &dives);
 	void cylinderAdded(dive *d, int pos);
 	void cylinderRemoved(dive *d, int pos);
@@ -159,7 +161,7 @@ inline DiveField::DiveField(int flags) :
 	water_temp((flags & WATER_TEMP) != 0),
 	atm_press((flags & ATM_PRESS) != 0),
 	divesite((flags & DIVESITE) != 0),
-	divemaster((flags & DIVEMASTER) != 0),
+	diveguide((flags & DIVEGUIDE) != 0),
 	buddy((flags & BUDDY) != 0),
 	rating((flags & RATING) != 0),
 	visibility((flags & VISIBILITY) != 0),
