@@ -1,12 +1,11 @@
 #include "xmp_parser.h"
 #include "subsurface-string.h"
+#include "subsurface-time.h"
 
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include <cctype>
 
-extern "C" timestamp_t utc_mktime(struct tm *tm); // declared in core/dive.h
-
 static timestamp_t parse_xmp_date(const char *date)
 {
 	// Format: "yyyy-mm-dd[Thh:mm[:ss[.ms]][-05:00]]"
@@ -61,7 +60,7 @@ static timestamp_t extract_timestamp_from_attributes(const xmlNode *node)
 		const xmlChar *ns = p->ns ? p->ns->prefix : nullptr;
 
 		// Check for xmp::CreateDate property
-		if (!strcmp((const char *)ns, "xmp") && !strcmp((const char *)p->name, "CreateDate")) {
+		if (same_string((const char *)ns, "xmp") && same_string((const char *)p->name, "CreateDate")) {
 			// We only support a single property value
 			if (!p->children || !p->children->content)
 				return 0;
