@@ -2,10 +2,7 @@
 #ifndef DIVEPICTUREWIDGET_H
 #define DIVEPICTUREWIDGET_H
 
-#include <QAbstractTableModel>
 #include <QListView>
-#include <QThread>
-#include <QFuture>
 
 class DivePictureWidget : public QListView {
 	Q_OBJECT
@@ -21,7 +18,4 @@ signals:
 	void zoomLevelChanged(int delta);
 };
 
-class DivePictureThumbnailThread : public QThread {
-};
-
 #endif
