@@ -9,6 +9,7 @@
 #include "core/qt-gui.h"
 #include "core/qthelper.h"
 #include "core/file.h"
+#include "core/device.h"
 #include "core/divesite.h"
 #include "core/trip.h"
 #include "core/save-html.h"
@@ -44,7 +45,7 @@ int main(int argc, char **argv)
 		qDebug() << "need --source and --output";
 		exit(1);
 	}
-	int ret = parse_file(qPrintable(source), &dive_table, &trip_table, &dive_site_table);
+	int ret = parse_file(qPrintable(source), &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table);
 	if (ret) {
 		fprintf(stderr, "parse_file returned %d\n", ret);
 		exit(1);
