@@ -164,6 +164,7 @@ ProfileScene::ProfileScene(double dpr, bool printMode, bool isGrayscale) :
 	addTissueItems<0,16>(dpr);
 
 	percentageItem->setZValue(1.0);
+	profileYAxis->setGridIsMultipleOfThree( qPrefDisplay::three_m_based_grid() );
 
 	// Add items to scene
 	addItem(diveComputerText);
@@ -304,6 +305,8 @@ void ProfileScene::updateAxes(bool diveHasHeartBeat, bool simplified)
 	if (width <= 10.0 * dpr)
 		return clear();
 
+	profileYAxis->setGridIsMultipleOfThree( qPrefDisplay::three_m_based_grid() );
+
 	// Place the fixed dive computer text at the bottom
 	double bottomBorder = sceneRect().height() - diveComputerText->height() - 2.0 * dpr * diveComputerTextBorder;
 	diveComputerText->setPos(0.0, bottomBorder + dpr * diveComputerTextBorder);
@@ -514,7 +517,7 @@ void ProfileScene::plotDive(const struct dive *dIn, int dcIn, DivePlannerPointsM
 	animatedAxes.push_back(timeAxis);
 	cylinderPressureAxis->setBounds(plotInfo.minpressure, plotInfo.maxpressure);
 
-	tankItem->setData(d, firstSecond, lastSecond);
+	tankItem->setData(d, currentdc, firstSecond, lastSecond);
 
 	if (ppGraphsEnabled(currentdc, simplified)) {
 		double max = prefs.pp_graphs.phe ? max_gas(plotInfo, &gas_pressures::he) : -1;
