@@ -48,6 +48,7 @@ ProfileWidget2::ProfileWidget2(DivePlannerPointsModel *plannerModelIn, double dp
 	currentState(INIT),
 	plannerModel(plannerModelIn),
 	zoomLevel(0),
+	zoomedPosition(0.0),
 #ifndef SUBSURFACE_MOBILE
 	toolTipItem(new ToolTipItem()),
 #endif
@@ -68,13 +69,6 @@ ProfileWidget2::ProfileWidget2(DivePlannerPointsModel *plannerModelIn, double dp
 #ifndef SUBSURFACE_MOBILE
 	setAcceptDrops(true);
 
-	addActionShortcut(Qt::Key_Escape, &ProfileWidget2::keyEscAction);
-	addActionShortcut(Qt::Key_Delete, &ProfileWidget2::keyDeleteAction);
-	addActionShortcut(Qt::Key_Up, &ProfileWidget2::keyUpAction);
-	addActionShortcut(Qt::Key_Down, &ProfileWidget2::keyDownAction);
-	addActionShortcut(Qt::Key_Left, &ProfileWidget2::keyLeftAction);
-	addActionShortcut(Qt::Key_Right, &ProfileWidget2::keyRightAction);
-
 	connect(Thumbnailer::instance(), &Thumbnailer::thumbnailChanged, this, &ProfileWidget2::updateThumbnail, Qt::QueuedConnection);
 	connect(&diveListNotifier, &DiveListNotifier::picturesRemoved, this, &ProfileWidget2::picturesRemoved);
 	connect(&diveListNotifier, &DiveListNotifier::picturesAdded, this, &ProfileWidget2::picturesAdded);
@@ -83,6 +77,7 @@ ProfileWidget2::ProfileWidget2(DivePlannerPointsModel *plannerModelIn, double dp
 	connect(&diveListNotifier, &DiveListNotifier::pictureOffsetChanged, this, &ProfileWidget2::pictureOffsetChanged);
 	connect(&diveListNotifier, &DiveListNotifier::divesChanged, this, &ProfileWidget2::divesChanged);
 	connect(&diveListNotifier, &DiveListNotifier::deviceEdited, this, &ProfileWidget2::replot);
+	connect(&diveListNotifier, &DiveListNotifier::diveComputerEdited, this, &ProfileWidget2::replot);
 #endif // SUBSURFACE_MOBILE
 
 #if !defined(QT_NO_DEBUG) && defined(SHOW_PLOT_INFO_TABLE)
@@ -123,14 +118,16 @@ ProfileWidget2::~ProfileWidget2()
 }
 
 #ifndef SUBSURFACE_MOBILE
-void ProfileWidget2::addActionShortcut(const Qt::Key shortcut, void (ProfileWidget2::*slot)())
+void ProfileWidget2::keyPressEvent(QKeyEvent *e)
 {
-	QAction *action = new QAction(this);
-	action->setShortcut(shortcut);
-	action->setShortcutContext(Qt::WindowShortcut);
-	addAction(action);
-	connect(action, &QAction::triggered, this, slot);
-	actionsForKeys[shortcut] = action;
+	switch (e->key()) {
+		case Qt::Key_Delete: return keyDeleteAction();
+		case Qt::Key_Up: return keyUpAction();
+		case Qt::Key_Down: return keyDownAction();
+		case Qt::Key_Left: return keyLeftAction();
+		case Qt::Key_Right: return keyRightAction();
+	}
+	QGraphicsView::keyPressEvent(e);
 }
 #endif // SUBSURFACE_MOBILE
 
@@ -288,6 +285,8 @@ void ProfileWidget2::divePlannerHandlerReleased()
 {
 	if (zoomLevel)
 		return;
+	if (currentState == EDIT)
+		emit stopMoved(1);
 	shouldCalculateMax = true;
 	replot();
 }
@@ -339,6 +338,8 @@ void ProfileWidget2::mouseDoubleClickEvent(QMouseEvent *event)
 		int minutes = lrint(profileScene->timeAxis->valueAt(mappedPos) / 60);
 		int milimeters = lrint(profileScene->profileYAxis->valueAt(mappedPos) / M_OR_FT(1, 1)) * M_OR_FT(1, 1);
 		plannerModel->addStop(milimeters, minutes * 60);
+		if (currentState == EDIT)
+			emit stopAdded();
 	}
 }
 
@@ -444,18 +445,10 @@ void ProfileWidget2::setEditState(const dive *d, int dc)
 	mouseFollowerHorizontal->setVisible(true);
 	mouseFollowerVertical->setVisible(true);
 	disconnectTemporaryConnections();
-	actionsForKeys[Qt::Key_Left]->setShortcut(Qt::Key_Left);
-	actionsForKeys[Qt::Key_Right]->setShortcut(Qt::Key_Right);
-	actionsForKeys[Qt::Key_Up]->setShortcut(Qt::Key_Up);
-	actionsForKeys[Qt::Key_Down]->setShortcut(Qt::Key_Down);
-	actionsForKeys[Qt::Key_Escape]->setShortcut(Qt::Key_Escape);
-	actionsForKeys[Qt::Key_Delete]->setShortcut(Qt::Key_Delete);
 
 	connectPlannerModel();
 
-	/* show the same stuff that the profile shows. */
-	currentState = EDIT; /* enable the add state. */
-	setBackgroundBrush(QColor("#A7DCFF"));
+	currentState = EDIT;
 
 	pointsReset();
 	repositionDiveHandlers();
@@ -470,17 +463,10 @@ void ProfileWidget2::setPlanState(const dive *d, int dc)
 	mouseFollowerHorizontal->setVisible(true);
 	mouseFollowerVertical->setVisible(true);
 	disconnectTemporaryConnections();
-	actionsForKeys[Qt::Key_Left]->setShortcut(Qt::Key_Left);
-	actionsForKeys[Qt::Key_Right]->setShortcut(Qt::Key_Right);
-	actionsForKeys[Qt::Key_Up]->setShortcut(Qt::Key_Up);
-	actionsForKeys[Qt::Key_Down]->setShortcut(Qt::Key_Down);
-	actionsForKeys[Qt::Key_Escape]->setShortcut(Qt::Key_Escape);
-	actionsForKeys[Qt::Key_Delete]->setShortcut(Qt::Key_Delete);
 
 	connectPlannerModel();
 
-	/* show the same stuff that the profile shows. */
-	currentState = PLAN; /* enable the add state. */
+	currentState = PLAN;
 	setBackgroundBrush(QColor("#D7E3EF"));
 
 	pointsReset();
@@ -602,9 +588,6 @@ void ProfileWidget2::contextMenuEvent(QContextMenuEvent *event)
 		changeMode->addAction(gettextFromC::tr(divemode_text_ui[PSCR]),
 				      [this, seconds](){ addDivemodeSwitch(seconds, PSCR); });
 
-	if (same_string(get_dive_dc_const(d, dc)->model, "manually added dive") || !get_dive_dc_const(d, dc)->samples)
-		m.addAction(tr("Edit the profile"), this, &ProfileWidget2::editCurrentDive);
-
 	if (DiveEventItem *item = dynamic_cast<DiveEventItem *>(sceneItem)) {
 		m.addAction(tr("Remove event"), [this,item] { removeEvent(item); });
 		m.addAction(tr("Hide similar events"), [this, item] { hideEvents(item); });
@@ -686,11 +669,14 @@ void ProfileWidget2::makeFirstDC()
 void ProfileWidget2::renameCurrentDC()
 {
 	bool ok;
+	struct divecomputer *currentdc = get_dive_dc(mutable_dive(), dc);
+	if (!currentdc)
+		return;
 	QString newName = QInputDialog::getText(this, tr("Edit nickname"),
-						tr("Set new nickname for %1 (serial %2):").arg(current_dc->model).arg(current_dc->serial),
-						QLineEdit::Normal, get_dc_nickname(current_dc), &ok);
+						tr("Set new nickname for %1 (serial %2):").arg(currentdc->model).arg(currentdc->serial),
+						QLineEdit::Normal, get_dc_nickname(currentdc), &ok);
 	if (ok)
-		Command::editDeviceNickname(current_dc, newName);
+		Command::editDeviceNickname(currentdc, newName);
 }
 
 void ProfileWidget2::hideEvents(DiveEventItem *item)
@@ -810,10 +796,6 @@ void ProfileWidget2::disconnectTemporaryConnections()
 		disconnect(plannerModel, &DivePlannerPointsModel::rowsMoved, this, &ProfileWidget2::pointsMoved);
 	}
 #endif
-	Q_FOREACH (QAction *action, actionsForKeys.values()) {
-		action->setShortcut(QKeySequence());
-		action->setShortcutContext(Qt::WidgetShortcut);
-	}
 }
 
 int ProfileWidget2::handleIndex(const DiveHandler *h) const
@@ -940,20 +922,31 @@ void ProfileWidget2::divePlannerHandlerMoved()
 	plannerModel->editStop(index, data);
 }
 
+std::vector<int> ProfileWidget2::selectedDiveHandleIndices() const
+{
+	std::vector<int> res;
+	res.reserve(scene()->selectedItems().size());
+	for (QGraphicsItem *item: scene()->selectedItems()) {
+		if (DiveHandler *handler = qgraphicsitem_cast<DiveHandler *>(item))
+			res.push_back(handleIndex(handler));
+	}
+	return res;
+}
+
 void ProfileWidget2::keyDownAction()
 {
 	if ((currentState != EDIT && currentState != PLAN) || !plannerModel)
 		return;
 
-	Q_FOREACH (QGraphicsItem *i, scene()->selectedItems()) {
-		if (DiveHandler *handler = qgraphicsitem_cast<DiveHandler *>(i)) {
-			int row = handleIndex(handler);
-			divedatapoint dp = plannerModel->at(row);
+	std::vector<int> handleIndices = selectedDiveHandleIndices();
+	for (int row: handleIndices) {
+		divedatapoint dp = plannerModel->at(row);
 
-			dp.depth.mm += M_OR_FT(1, 5);
-			plannerModel->editStop(row, dp);
-		}
+		dp.depth.mm += M_OR_FT(1, 5);
+		plannerModel->editStop(row, dp);
 	}
+	if (currentState == EDIT && !handleIndices.empty())
+		emit stopMoved(handleIndices.size()); // TODO: Accumulate key moves
 }
 
 void ProfileWidget2::keyUpAction()
@@ -961,18 +954,18 @@ void ProfileWidget2::keyUpAction()
 	if ((currentState != EDIT && currentState != PLAN) || !plannerModel)
 		return;
 
-	Q_FOREACH (QGraphicsItem *i, scene()->selectedItems()) {
-		if (DiveHandler *handler = qgraphicsitem_cast<DiveHandler *>(i)) {
-			int row = handleIndex(handler);
-			divedatapoint dp = plannerModel->at(row);
+	std::vector<int> handleIndices = selectedDiveHandleIndices();
+	for (int row: handleIndices) {
+		divedatapoint dp = plannerModel->at(row);
 
-			if (dp.depth.mm <= 0)
-				continue;
+		if (dp.depth.mm <= 0)
+			continue;
 
-			dp.depth.mm -= M_OR_FT(1, 5);
-			plannerModel->editStop(row, dp);
-		}
+		dp.depth.mm -= M_OR_FT(1, 5);
+		plannerModel->editStop(row, dp);
 	}
+	if (currentState == EDIT && !handleIndices.empty())
+		emit stopMoved(handleIndices.size()); // TODO: Accumulate key moves
 }
 
 void ProfileWidget2::keyLeftAction()
@@ -980,18 +973,18 @@ void ProfileWidget2::keyLeftAction()
 	if ((currentState != EDIT && currentState != PLAN) || !plannerModel)
 		return;
 
-	Q_FOREACH (QGraphicsItem *i, scene()->selectedItems()) {
-		if (DiveHandler *handler = qgraphicsitem_cast<DiveHandler *>(i)) {
-			int row = handleIndex(handler);
-			divedatapoint dp = plannerModel->at(row);
+	std::vector<int> handleIndices = selectedDiveHandleIndices();
+	for (int row: handleIndices) {
+		divedatapoint dp = plannerModel->at(row);
 
-			if (dp.time / 60 <= 0)
-				continue;
+		if (dp.time / 60 <= 0)
+			continue;
 
-			dp.time -= 60;
-			plannerModel->editStop(row, dp);
-		}
+		dp.time -= 60;
+		plannerModel->editStop(row, dp);
 	}
+	if (currentState == EDIT && !handleIndices.empty())
+		emit stopMoved(handleIndices.size()); // TODO: Accumulate key moves
 }
 
 void ProfileWidget2::keyRightAction()
@@ -999,15 +992,15 @@ void ProfileWidget2::keyRightAction()
 	if ((currentState != EDIT && currentState != PLAN) || !plannerModel)
 		return;
 
-	Q_FOREACH (QGraphicsItem *i, scene()->selectedItems()) {
-		if (DiveHandler *handler = qgraphicsitem_cast<DiveHandler *>(i)) {
-			int row = handleIndex(handler);
-			divedatapoint dp = plannerModel->at(row);
+	std::vector<int> handleIndices = selectedDiveHandleIndices();
+	for (int row: handleIndices) {
+		divedatapoint dp = plannerModel->at(row);
 
-			dp.time += 60;
-			plannerModel->editStop(row, dp);
-		}
+		dp.time += 60;
+		plannerModel->editStop(row, dp);
 	}
+	if (currentState == EDIT && !handleIndices.empty())
+		emit stopMoved(handleIndices.size()); // TODO: Accumulate key moves
 }
 
 void ProfileWidget2::keyDeleteAction()
@@ -1015,29 +1008,15 @@ void ProfileWidget2::keyDeleteAction()
 	if ((currentState != EDIT && currentState != PLAN) || !plannerModel)
 		return;
 
-	QVector<int> selectedIndices;
-	Q_FOREACH (QGraphicsItem *i, scene()->selectedItems()) {
-		if (DiveHandler *handler = qgraphicsitem_cast<DiveHandler *>(i)) {
-			selectedIndices.push_back(handleIndex(handler));
-			handler->hide();
-		}
+	std::vector<int> handleIndices = selectedDiveHandleIndices();
+	// For now, we have to convert to QVector.
+	for (int index: handleIndices)
+		handles[index]->hide();
+	if (!handleIndices.empty()) {
+		plannerModel->removeSelectedPoints(handleIndices);
+		if (currentState == EDIT)
+			emit stopRemoved(handleIndices.size());
 	}
-	if (!selectedIndices.isEmpty())
-		plannerModel->removeSelectedPoints(selectedIndices);
-}
-
-void ProfileWidget2::keyEscAction()
-{
-	if ((currentState != EDIT && currentState != PLAN) || !plannerModel)
-		return;
-
-	if (scene()->selectedItems().count()) {
-		scene()->clearSelection();
-		return;
-	}
-
-	if (plannerModel->isPlanner())
-		plannerModel->cancelPlan();
 }
 
 void ProfileWidget2::clearPictures()
