@@ -7,9 +7,9 @@
 
 #include <memory>
 #include <vector>
-#include <QFont>
 
 class QFontMetrics;
+class StatsTheme;
 
 class Legend : public ChartRectItem {
 public:
@@ -23,12 +23,12 @@ private:
 		QBrush rectBrush;
 		QPointF pos;
 		double width;
-		Entry(const QString &name, int idx, int numBins, const QFontMetrics &fm);
+		Entry(const QString &name, int idx, int numBins, const QFontMetrics &fm, const StatsTheme &);
 	};
 	int displayedItems;
 	double width;
 	double height;
-	QFont font;
+	const StatsTheme &theme; // Set once in constructor.
 	// The position is specified with respect to the center and in relative terms
 	// with respect to the canvas.
 	QPointF centerPos;
